summaryrefslogtreecommitdiffstats
path: root/parts/replace/replaceitem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'parts/replace/replaceitem.cpp')
-rw-r--r--parts/replace/replaceitem.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/parts/replace/replaceitem.cpp b/parts/replace/replaceitem.cpp
index 087e2b1f..853c170d 100644
--- a/parts/replace/replaceitem.cpp
+++ b/parts/replace/replaceitem.cpp
@@ -45,18 +45,18 @@ void ReplaceItem::setChecked( bool checked )
{
if ( !isFile() ) // this is a child item
{
- if ( checked || !(tqparent()->hasCheckedChildren()))
+ if ( checked || !(parent()->hasCheckedChildren()))
{
- if ( tqparent()->isOn() != checked )
+ if ( parent()->isOn() != checked )
{
- tqparent()->_clicked = false;
- tqparent()->setOn( checked );
+ parent()->_clicked = false;
+ parent()->setOn( checked );
}
}
return;
}
// this is a tqparent item, set self and tqchildren
ReplaceItem * item = firstChild();
while ( item )
{
@@ -45,18 +45,18 @@ void ReplaceItem::setChecked( bool checked )
return;
}
- // this is a tqparent item, set self and tqchildren
+ // this is a parent item, set self and tqchildren
ReplaceItem * item = firstChild();
while ( item )